import React from 'react';
import PropTypes from 'prop-types';
import { Button, Icon } from "./..";
/**
 * @category communication
 * @component alert
 * @variations collab-ui-react
 */

var Alert = function Alert(props) {
  var show = props.show,
      onHide = props.onHide,
      type = props.type,
      closable = props.closable,
      title = props.title,
      message = props.message;
  return show && React.createElement("div", {
    className: "cui-alert cui-alert--" + type
  }, React.createElement("div", {
    className: "cui-alert__icon"
  }), React.createElement("div", {
    className: 'cui-alert__content'
  }, React.createElement("div", {
    className: "cui-alert__title"
  }, title), React.createElement("div", {
    className: "cui-alert__message"
  }, message)), closable && React.createElement("div", {
    className: "cui-alert__button"
  }, React.createElement(Button, {
    children: React.createElement(Icon, {
      name: "cancel_16"
    }),
    onClick: onHide,
    ariaLabel: "close",
    circle: true,
    large: true
  })));
};

Alert.defaultProps = {
  title: '',
  message: '',
  type: 'info',
  closable: false,
  onHide: null
};
Alert.propTypes = {
  /**
   * optional Alert Title
   */
  title: PropTypes.string,

  /**
   * optional Alert Message
   */
  message: PropTypes.string,

  /**
   * show/hide Alert.
   */
  show: PropTypes.bool.isRequired,

  /**
   * size of the Alert.
   */
  type: PropTypes.oneOf(['info', 'success', 'warning', 'error']),

  /**
   * callback function invoked on close of the Alert. Alert can be closed on click of cross button or esc key.
   * onHide is mandatory props, if not passed Alert can not be closed.
   */
  onHide: PropTypes.func,

  /**
   *  To show/hide Close CTA of the Alert.
   */
  closable: PropTypes.bool
};
Alert.displayName = 'Alert';
export default Alert;
/**
* @name Alerts
* @description Create the type of Alert (info, success, warning, or error) by passing in the type prop.
*
* @category communication
* @component alert
* @section default
*
* @js

import {
  Button,
  AlertContainer
} from '@collab-ui/react';

export default class Default extends React.PureComponent {
  state = {
    alertMessage: 'Who\'s awesome?  You are!'
  }

  render() {
    let alertContainer;
    return (
      <section>
        <div>
          <div className='row'>
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertContainer.info(
                'Alert',
                this.state.alertMessage,
                () => console.log('onHide info')
              )}
              children='Info/Default'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertContainer.success(
                'Alert',
                this.state.alertMessage,
                () => console.log('onHide info')
              )}
              children='Success'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertContainer.warning(
                'Alert',
                this.state.alertMessage,
                () => console.log('onHide info')
              )}
              children='Warning'
              color='primary'
              size='large'
            />
          </div>
          <div className='row'>
            <br />
            <Button
              ariaLabel='Click to Open'
              onClick={() => alertContainer.error(
                'Alert',
                this.state.alertMessage,
                () => console.log('onHide info')
              )}
              children='Error'
              color='primary'
              size='large'
            />
          </div>
        </div>
        <br />
        <AlertContainer
          ref={ref => alertContainer = ref}
          orderNewest={false}
        />
      </section>
    );
  }
}

**/