"use strict";

exports.__esModule = true;
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _ = require("./..");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

/**
 * @category controls
 * @component editable-textfield
 * @variations collab-ui-react
 */
var EditableTextfield =
/*#__PURE__*/
function (_React$PureComponent) {
  _inheritsLoose(EditableTextfield, _React$PureComponent);

  function EditableTextfield() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$PureComponent.call.apply(_React$PureComponent, [this].concat(args)) || this;
    _this.state = {
      isEditing: false,
      inputText: _this.props.inputText
    };

    _this.componentDidUpdate = function () {
      if (_this.state.isEditing && _this.editText) {
        _this.editText.focus();
      }
    };

    _this.handleDoneEditing = function (value) {
      var handleDoneEditing = _this.props.handleDoneEditing;

      _this.setState({
        isEditing: false,
        inputText: value
      });

      if (handleDoneEditing) {
        handleDoneEditing(value);
      }
    };

    _this.handleClick = function () {
      var disabled = _this.props.disabled;

      if (disabled) {
        return;
      } else {
        _this.setState({
          isEditing: true
        });
      }
    };

    _this.handleKey = function (e) {
      var disabled = _this.props.disabled;
      e.stopPropagation();
      e.preventDefault();

      if (disabled) {
        return;
      } else {
        _this.setState({
          isEditing: true
        });
      }
    };

    _this.handleDoneKeyDown = function (e) {
      if (e.keyCode === 27) {
        _this.setState({
          isEditing: false
        });
      } else if (e.keyCode === 13) {
        _this.handleDoneEditing(e.target.value);
      }
    };

    return _this;
  }

  var _proto = EditableTextfield.prototype;

  _proto.render = function render() {
    var _this2 = this;

    var className = this.props.className;
    var _this$state = this.state,
        isEditing = _this$state.isEditing,
        inputText = _this$state.inputText;
    return _react.default.createElement("div", null, isEditing && _react.default.createElement(_.Input, {
      className: 'cui-editable-textfield' + ' cui-editable-textfield__editing' + ("" + (className && " " + className || '')),
      inputRef: function inputRef(input) {
        _this2.editText = input;
      },
      defaultValue: inputText,
      htmlId: "editText",
      name: "editText",
      onDoneEditing: this.handleDoneEditing,
      onKeyDown: this.handleDoneKeyDown
    }), !isEditing && _react.default.createElement("span", {
      role: "button",
      tabIndex: 0,
      className: 'cui-editable-textfield' + ' cui-editable-textfield__span' + ("" + (className && " " + className || '')),
      onClick: this.handleClick,
      onKeyPress: this.handleKey
    }, inputText));
  };

  return EditableTextfield;
}(_react.default.PureComponent);

EditableTextfield.displayName = 'EditableTextfield';
EditableTextfield.propTypes = {
  /**
   * css class names
   */
  className: _propTypes.default.string,

  /**
   * text to be shown
   */
  inputText: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.number]),

  /**
   * optional disable
   */
  disabled: _propTypes.default.bool,

  /**
   * optional function for blur
   */
  handleDoneEditing: _propTypes.default.func
};
EditableTextfield.defaultProps = {
  className: '',
  inputText: '',
  disabled: false,
  handleDoneEditing: null
};
var _default = EditableTextfield;
/**
* @name Default EditableTextfield
* @description default
*
* @category controls
* @component editable-textfield
* @section default
*
* @js

export default class PlaygroundComponent extends React.Component {
  valueChange = (value) => {
    newValue = value;
  }

  render() {
    return (
      <div>
        <div className="docui-example docui-example--spacing" style={{padding: '16px'}}>
          <EditableTextfield inputText='Hello World' handleDoneEditing={(value) =>this.consoleChange(value)}/>
        </div>
        <div className='cui--dark docs-example--dark' style={{padding: '16px'}}>
          <EditableTextfield inputText='Hello Dark World'/>
        </div>
    </div>
    );
  }
}

**/

exports.default = _default;